pub fn block_in_place_on_nautilus<F, R>(f: F) -> Rwhere
F: FnOnce() -> R,Expand description
Runs f with block_in_place on a thread owned by the Nautilus runtime.
Panics
Panics from a LocalSet driven on a Nautilus-owned thread, including any LocalSet driven
against an injected Nautilus runtime, because Tokio does not permit block_in_place while
polling local tasks.